@@ -22,8 +22,8 @@ impl Application {
 }
 
 impl wita::EventHandler for Application {
-    fn closed(&mut self, window: &wita::Window) {
-        println!("closed {}", window.title());
+    fn closed(&mut self, ev: wita::event::Closed) {
+        println!("closed {}", ev.window.title());
     }
 }
 
