@@ -1,5 +1,3 @@
-use std::path::Path;
-
 struct Application {
     accept_drag_files: bool,
 }
@@ -17,25 +15,14 @@ impl Application {
 }
 
 impl wita::EventHandler for Application {
-    fn drop_files(
-        &mut self,
-        _: &wita::Window,
-        paths: &[&Path],
-        position: wita::PhysicalPosition<i32>,
-    ) {
-        println!("drop files: {:?}, {:?}", paths, position);
+    fn drop_files(&mut self, ev: wita::event::DropFiles) {
+        println!("drop files: {:?}, {:?}", ev.paths, ev.position);
     }
 
-    fn key_input(
-        &mut self,
-        window: &wita::Window,
-        code: wita::KeyCode,
-        state: wita::KeyState,
-        _: bool,
-    ) {
-        if state == wita::KeyState::Pressed && code.vkey == wita::VirtualKey::Char('T') {
+    fn key_input(&mut self, ev: wita::event::KeyInput) {
+        if ev.state == wita::KeyState::Pressed && ev.key_code.vkey == wita::VirtualKey::Char('T') {
             self.accept_drag_files = !self.accept_drag_files;
-            window.accept_drag_files(self.accept_drag_files);
+            ev.window.accept_drag_files(self.accept_drag_files);
             if self.accept_drag_files {
                 println!("enabled accept_drag_files");
             } else {
