@@ -5,7 +5,7 @@ use crate::{
     context::*,
     device::*,
     event,
-    event::EventHandler,
+    event::{EventHandler, ResizingEdge},
     geometry::*,
     ime,
     window::{Style, Window},
@@ -428,10 +428,22 @@ pub(crate) extern "system" fn window_proc<T: EventHandler + 'static>(
                     (rc.right - rc.left - d.width) as u32,
                     (rc.bottom - rc.top - d.height) as u32,
                 );
+                let edge = match wparam.0 as u32 {
+                    WMSZ_LEFT => ResizingEdge::Left,
+                    WMSZ_RIGHT => ResizingEdge::Right,
+                    WMSZ_TOP => ResizingEdge::Top,
+                    WMSZ_TOPLEFT => ResizingEdge::TopLeft,
+                    WMSZ_TOPRIGHT => ResizingEdge::TopRight,
+                    WMSZ_BOTTOM => ResizingEdge::Bottom,
+                    WMSZ_BOTTOMLEFT => ResizingEdge::BottomLeft,
+                    WMSZ_BOTTOMRIGHT => ResizingEdge::BottomRight,
+                    _ => unreachable!(),
+                };
                 call_handler(|eh: &mut T, _| {
                     eh.resizing(event::Resizing {
                         window: handle,
                         size: &mut size,
+                        edge,
                     });
                 });
                 let tmp = adjust_window_rect(
