@@ -703,6 +703,9 @@ impl Window {
     #[inline]
     pub fn show(&self) {
         unsafe {
+            if self.is_minimized() {
+                self.restore();
+            }
             ShowWindowAsync(self.hwnd.0, SW_SHOW);
         }
     }
@@ -714,6 +717,37 @@ impl Window {
         }
     }
 
+    #[inline]
+    pub fn minimize(&self) {
+        unsafe {
+            ShowWindowAsync(self.hwnd.0, SW_MINIMIZE);
+        }
+    }
+
+    #[inline]
+    pub fn maximize(&self) {
+        unsafe {
+            ShowWindowAsync(self.hwnd.0, SW_MAXIMIZE);
+        }
+    }
+
+    #[inline]
+    pub fn restore(&self) {
+        unsafe {
+            ShowWindowAsync(self.hwnd.0, SW_RESTORE);
+        }
+    }
+
+    #[inline]
+    pub fn is_minimized(&self) -> bool {
+        unsafe { IsIconic(self.hwnd.0).as_bool() }
+    }
+
+    #[inline]
+    pub fn is_maximized(&self) -> bool {
+        unsafe { IsZoomed(self.hwnd.0).as_bool() }
+    }
+
     #[inline]
     pub fn redraw(&self) {
         unsafe {
